deriva.transfer.download.processors.query package
=================================================

Submodules
----------

deriva.transfer.download.processors.query.bag\_fetch\_query\_processor module
-----------------------------------------------------------------------------

.. automodule:: deriva.transfer.download.processors.query.bag_fetch_query_processor
    :members:
    :undoc-members:
    :show-inheritance:

deriva.transfer.download.processors.query.base\_query\_processor module
-----------------------------------------------------------------------

.. automodule:: deriva.transfer.download.processors.query.base_query_processor
    :members:
    :undoc-members:
    :show-inheritance:


deriva.transfer.download.processors.query.file\_download\_query\_processor module
---------------------------------------------------------------------------------

.. automodule:: deriva.transfer.download.processors.query.file_download_query_processor
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: deriva.transfer.download.processors.query
    :members:
    :undoc-members:
    :show-inheritance:
